@@ -3,8 +3,7 @@ import urllib.request
 import zipfile
 import os
 import pathlib
-from Pragmatic import Pragmatic
-
+from .FileUtils import GetDataDir
 
 
 pbar = None
@@ -24,9 +23,9 @@ def show_progress(block_num, block_size, total_size):
 		pbar.finish()
 		pbar = None
 
-def Get(name, release):
+def GetReleaseFile(name, release):
 	# Download
-	downloadPath = os.path.join(Pragmatic.GetDataDir(), f'{name}.zip')
+	downloadPath = os.path.join(GetDataDir(), f'{name}.zip')
 	if not pathlib.Path(downloadPath).exists():
 		print(f'Downloading {name} build')
 		urllib.request.urlretrieve(f'https://github.com/QEDengine/Pragmatic/releases/download/{release}/{name}.zip', downloadPath, show_progress)
@@ -36,7 +35,9 @@ def Get(name, release):
 	with zipfile.ZipFile(downloadPath, 'r') as zip_ref:
 		total = len(zip_ref.filelist)
 		for x, file in enumerate(zip_ref.filelist):
-			zip_ref.extract(member=file, path=os.path.join(Pragmatic.GetDataDir(), name))
+			zip_ref.extract(member=file, path=os.path.join(GetDataDir(), name))
 			show_progress(x, 1, total)
 
+	# Delete zip
+	os.remove(downloadPath)
 	print('Done!')
\ No newline at end of file
