@@ -4,6 +4,6 @@
 """Pragmatic.__main__: executed when bootstrap directory is called as script."""
  
  
-from .Pragmatic import Main
+from .Pragmatic import main
 
-Main()
\ No newline at end of file
+main()
\ No newline at end of file
